value property
The current value stored in this notifier.
When the value is replaced with something that is not equal to the old value as evaluated by the equality operator ==, this class notifies its listeners.
Implementation
@override
T get value => _value;
Implementation
@override
set value(TextEditingValue newValue) {
final token = _extractTokenAtCursor(newValue);
if (token.isNotEmpty) {
final match = _combinedPattern.firstMatch(token);
if (match != null) {
_onMatch?.call(_createMatchedModelFromMatch(match));
} else {
_onNonMatch?.call(token);
}
}
super.value = newValue;
}