RegexPatternTextStyle<T> class

Constructors

RegexPatternTextStyle({required String regexPattern, required TextStyle textStyle, T? type, bool caseSensitive = false, bool multiLine = true})
const

Properties

caseSensitive bool
final
hashCode int
The hash code for this object.
no setterinherited
multiLine bool
final
regexPattern String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
final
type → T?
final

Methods

matches(String value) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited